<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch"
      label-width="68px">
      <el-form-item label="科目类别名称" prop="subjectTypeName">
        <el-input v-model="queryParams.subjectTypeName" placeholder="请输入科目类别名称" clearable
          @keyup.enter.native="handleQuery" />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索
        </el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
          v-hasPermi="['finance:subjectType:add']">新增</el-button>
      </el-col>
      <el-col :span="1.5">
                <el-button type="info" plain icon="el-icon-sort" size="mini" @click="toggleExpandAll">展开/折叠</el-button>
      </el-col>

      <el-col :span="1.5">
        <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
          v-hasPermi="['finance:subjectType:export']">导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-if="refreshTable" v-loading="loading" row-key="subjectTypeId"
      :data="subjectTypeList" :default-expand-all="isExpandAll"
      :tree-props="{ children: 'children', hasChildren: 'hasChildren' }">

      <el-table-column  label="科目类别名称" align="left" prop="subjectTypeName" />
      <el-table-column label="显示顺序" align="left" prop="orderNum" />
      <el-table-column label="操作" align="left" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
            v-hasPermi="['finance:subjectType:edit']">修改</el-button>
          <el-button size="mini" type="text" icon="el-icon-plus" @click="handleAdd(scope.row)"
            v-hasPermi="['system:dept:add']">新增</el-button>
          <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
            v-hasPermi="['finance:subjectType:remove']">删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <!-- 添加或修改科目类别对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="上级科目" prop="parentId">
          <treeselect v-model="form.parentId" :options="subjectTypeOptions" :normalizer="normalizer"
            placeholder="选择上级科目类别" />
        </el-form-item>
        <el-form-item label="科目类别名称" prop="subjectTypeName">
          <el-input v-model="form.subjectTypeName" placeholder="请输入科目类别名称" />
        </el-form-item>
        <el-form-item label="显示顺序" prop="orderNum">
          <el-input v-model="form.orderNum" placeholder="请输入显示顺序" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listAllSubjectType,
  getSubjectType,
  delSubjectType,
  addSubjectType,
  updateSubjectType,
  listExcludeChild,
} from "@/api/finance/subjectType";
import Treeselect from "@riophae/vue-treeselect";
import "@riophae/vue-treeselect/dist/vue-treeselect.css";

export default {
  name: "SubjectType",
  components: { Treeselect },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 科目类别表格树数据
      subjectTypeList: [],
      // 科目类别树选项
      subjectTypeOptions: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 是否展开，默认全部展开
      isExpandAll: true,
      // 重新渲染表格状态
      refreshTable: true,
      // 查询参数
      queryParams: {
        subjectTypeName: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        parentId: [
          { required: true, message: "上级id不能为空", trigger: "blur" },
        ],
      },
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询科目类别列表 */
    getList() {
      this.loading = true;
      listAllSubjectType(this.queryParams).then((response) => {
        // this.subjectTypeList = response.rows;
        this.subjectTypeList = this.handleTree(response.data, "subjectTypeId");
        this.loading = false;
      });
    },
    /** 转换科目类别数据结构 */
    normalizer(node) {
      if (node.children && !node.children.length) {
        delete node.children;
      }
      return {
        id: node.subjectTypeId,
        label: node.subjectTypeName,
        children: node.children,
      };
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        subjectTypeId: null,
        parentId: null,
        subjectTypeName: null,
        orderNum: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    /** 新增按钮操作 */
    handleAdd(row) {
      this.reset();
      if (row != undefined) {
        this.form.parentId = row.subjectTypeId;
      }
      this.open = true;
      this.title = "添加科目类别";
      listAllSubjectType().then((response) => {
        this.subjectTypeOptions = this.handleTree(
          response.data,
          "subjectTypeId"
        );
        if (this.subjectTypeOptions.length == 0) {
        }
        const noResultsOptions = {
          subjectTypeId: this.form.parentId || 0,
          subjectTypeName: this.form.parentName || "根节点",
          children: this.subjectTypeOptions,
        };
        this.subjectTypeOptions = [noResultsOptions];
      });
    },
    /** 展开/折叠操作 */
    toggleExpandAll() {
      this.refreshTable = false;
      this.isExpandAll = !this.isExpandAll;
      this.$nextTick(() => {
        this.refreshTable = true;
      });
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const subjectTypeId = row.subjectTypeId;
      getSubjectType(subjectTypeId).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改科目类别";
        listExcludeChild(row.subjectTypeId).then((response) => {
          this.subjectTypeOptions = this.handleTree(
            response.data,
            "subjectTypeId"
          );
          if (this.subjectTypeOptions.length == 0) {
          }
          const noResultsOptions = {
            subjectTypeId: this.form.parentId || 0,
            subjectTypeName: this.form.parentName || "根节点",
            children: this.subjectTypeOptions,
          };
          this.subjectTypeOptions = [noResultsOptions];
        });
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.subjectTypeId != null) {
            updateSubjectType(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addSubjectType(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const subjectTypeIds = row.subjectTypeId || this.ids;
      this.$modal
        .confirm('是否确认删除科目类别编号为"' + subjectTypeIds + '"的数据项？')
        .then(function () {
          return delSubjectType(subjectTypeIds);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download(
        "finance/subjectType/export",
        {
          ...this.queryParams,
        },
        `subjectType_${new Date().getTime()}.xlsx`
      );
    },
  },
};
</script>
